# Generated by Django 4.1.3 on 2023-01-03 06:25

from django.db import migrations

import formkit_ninja.fields


class Migration(migrations.Migration):

    dependencies = [
        ("formkit_ninja", "0005_delete_schemacondition_and_more"),
    ]

    operations = [
        migrations.AddField(
            model_name="formkitschemanode",
            name="placeholder",
            field=formkit_ninja.fields.TranslatedField(blank=True, null=True),
        ),
    ]
